Component
=================================

.. currentmodule:: enaml.widgets.component

.. autoclass:: Component


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_component.QtComponent
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_component.QtComponent

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_component.WXComponent
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_component.WXComponent
